using System.IO;

public class Hello
{
    public static void Main(string[] args)
    {
        System.Console.WriteLine("Hello Mono!");
        System.Console.WriteLine("I was compiled by the compiled compiler!");

        string checkfile = "hello.cs";
        if (File.Exists(checkfile))
        {
            System.Console.WriteLine("Check for file: " + checkfile);
        }
    }
}
